@@ -126,7 +126,7 @@ pub enum Error {
     EndpointSetup(#[from] qp2p::ClientEndpointError),
     /// QuicP2p error.
     #[error(transparent)]
-    QuicP2p(#[from] qp2p::SendError),
+    QuicP2p(#[from] qp2p::RpcError),
     /// Bincode error
     #[error(transparent)]
     Serialisation(#[from] Box<bincode::ErrorKind>),
@@ -159,3 +159,15 @@ impl From<(ErrorMessage, OperationId)> for Error {
         Self::ErrorMessage { source, op_id }
     }
 }
+
+impl From<qp2p::SendError> for Error {
+    fn from(error: qp2p::SendError) -> Self {
+        Self::QuicP2p(error.into())
+    }
+}
+
+impl From<qp2p::RecvError> for Error {
+    fn from(error: qp2p::RecvError) -> Self {
+        Self::QuicP2p(error.into())
+    }
+}
