@@ -182,10 +182,6 @@ impl Core {
             .finalise_dkg(self.section.chain().last_key())
             .await;
 
-        if new.prefix != old.prefix {
-            info!("Split");
-        }
-
         if new.last_key != old.last_key {
             if new.is_elder {
                 info!(
@@ -257,6 +253,10 @@ impl Core {
             };
 
             let event = if let Some(sibling_elders) = sibling_elders {
+                info!("Split");
+                // In case of split, send AEUpdate to sibling new elder nodes.
+                commands.extend(self.send_ae_update_to_sibling_section(&old)?);
+
                 Event::SectionSplit {
                     elders,
                     sibling_elders,
