@@ -299,15 +299,14 @@ impl Core {
     pub(crate) async fn get_chunk_holder_adults(&self, target: &XorName) -> BTreeSet<XorName> {
         let full_adults = self.full_adults().await;
         // TODO: reuse our_adults_sorted_by_distance_to API when core is merged into upper layer
-        let adults = self
-            .section()
-            .adults()
-            .copied()
-            .map(|p2p_node| *p2p_node.name());
+        let adults = self.section().adults();
 
-        let mut candidates = adults
+        let adults_names = adults.iter().map(|p2p_node| *p2p_node.name());
+
+        let mut candidates = adults_names
+            .into_iter()
             .sorted_by(|lhs, rhs| target.cmp_distance(lhs, rhs))
-            .filter(|name| !full_adults.contains(name))
+            .filter(|peer| !full_adults.contains(peer))
             .take(CHUNK_COPY_COUNT)
             .collect::<BTreeSet<_>>();
         trace!(
